# sentiment-spanish


[![PyPI version](https://badge.fury.io/py/sentiment_analysis_spanish.svg)](https://badge.fury.io/py/sentiment_analysis_spanish)




Import the package

```
from sentiment_analysis_spanish import sentiment_analysis

```

